.. _reference:

================
 dipy reference
================

:Release: |version|
:Date: |today|

This reference manual details functions, modules, and objects included
in dipy.

.. toctree::

    core
    align
    boots
    data
    external
    io
    reconst
    tracking
    viz
